package com.chelvc.framework.security.config;

import java.util.Collections;
import java.util.List;

import lombok.Data;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Configuration;

/**
 * 信息安全配置属性
 *
 * @author Woody
 * @date 2024/1/30
 */
@Data
@Configuration
@ConfigurationProperties("security")
public class SecurityProperties {
    /**
     * 安全密钥
     */
    private String secret;

    /**
     * 请求时长（毫秒）
     */
    private long duration = 60 * 1000;

    /**
     * 忽略地址列表
     */
    private List<String> ignores = Collections.emptyList();

    /**
     * 认证配置
     */
    private final Authorize authorize = new Authorize();

    /**
     * 认证信息
     */
    @Data
    public static class Authorize {
        /**
         * 令牌密钥
         */
        private String secret;

        /**
         * 是否区分应用范围
         */
        private boolean scoped;
    }
}
